diff --git a/trunk/doc/CHANGELOG.md b/trunk/doc/CHANGELOG.md
index 966b6697a..c2869373f 100644
--- a/trunk/doc/CHANGELOG.md
+++ b/trunk/doc/CHANGELOG.md
@@ -7,6 +7,7 @@ The changelog for SRS.
## SRS 6.0 Changelog
+* v6.0, 2025-02-20, Merge [#4253](https://github.com/ossrs/srs/pull/4253): fix typo about heartbeat. v6.0.161 (#4253)
* v6.0, 2025-02-19, Merge [#4291](https://github.com/ossrs/srs/pull/4291): fix ci error. v6.0.160 (#4291)
* v6.0, 2025-01-14, Merge [#4271](https://github.com/ossrs/srs/pull/4271): update copyright to 2025. v6.0.159 (#4271)
* v6.0, 2024-10-31, Merge [#4216](https://github.com/ossrs/srs/pull/4216): fix hls error when stream has extension. v6.0.158 (#4216)
@@ -172,6 +173,7 @@ The changelog for SRS.
## SRS 5.0 Changelog
+* v5.0, 2025-02-20, Merge [#4253](https://github.com/ossrs/srs/pull/4253): fix typo about heartbeat. v5.0.220 (#4253)
* v5.0, 2025-02-19, Merge [#4291](https://github.com/ossrs/srs/pull/4291): fix ci error. v5.0.219 (#4291)
* v5.0, 2025-01-14, Merge [#4271](https://github.com/ossrs/srs/pull/4271): update copyright to 2025. v5.0.218 (#4271)
* v5.0, 2024-10-31, Merge [#4216](https://github.com/ossrs/srs/pull/4216): fix hls error when stream has extension. v5.0.217 (#4216)
diff --git a/trunk/src/app/srs_app_config.cpp b/trunk/src/app/srs_app_config.cpp
index 2a9461faa..d74f4b410 100644
--- a/trunk/src/app/srs_app_config.cpp
+++ b/trunk/src/app/srs_app_config.cpp
@@ -2405,7 +2405,7 @@ srs_error_t SrsConfig::check_normal_config()
}
}
if (true) {
- SrsConfDirective* conf = get_heartbeart();
+ SrsConfDirective* conf = get_heartbeat();
for (int i = 0; conf && i < (int)conf->directives.size(); i++) {
string n = conf->at(i)->name;
if (n != "enabled" && n != "interval" && n != "url"
@@ -8708,7 +8708,7 @@ string SrsConfig::get_vhost_http_remux_mount(string vhost)
return conf->arg0();
}
-SrsConfDirective* SrsConfig::get_heartbeart()
+SrsConfDirective* SrsConfig::get_heartbeat()
{
return root->get("heartbeat");
}
@@ -8719,7 +8719,7 @@ bool SrsConfig::get_heartbeat_enabled()
static bool DEFAULT = false;
- SrsConfDirective* conf = get_heartbeart();
+ SrsConfDirective* conf = get_heartbeat();
if (!conf) {
return DEFAULT;
}
@@ -8738,7 +8738,7 @@ srs_utime_t SrsConfig::get_heartbeat_interval()
static srs_utime_t DEFAULT = (srs_utime_t)(10 * SRS_UTIME_SECONDS);
- SrsConfDirective* conf = get_heartbeart();
+ SrsConfDirective* conf = get_heartbeat();
if (!conf) {
return DEFAULT;
}
@@ -8757,7 +8757,7 @@ string SrsConfig::get_heartbeat_url()
static string DEFAULT = "http://" SRS_CONSTS_LOCALHOST ":8085/api/v1/servers";
- SrsConfDirective* conf = get_heartbeart();
+ SrsConfDirective* conf = get_heartbeat();
if (!conf) {
return DEFAULT;
}
@@ -8776,7 +8776,7 @@ string SrsConfig::get_heartbeat_device_id()
static string DEFAULT = "";
- SrsConfDirective* conf = get_heartbeart();
+ SrsConfDirective* conf = get_heartbeat();
if (!conf) {
return DEFAULT;
}
@@ -8795,7 +8795,7 @@ bool SrsConfig::get_heartbeat_summaries()
static bool DEFAULT = false;
- SrsConfDirective* conf = get_heartbeart();
+ SrsConfDirective* conf = get_heartbeat();
if (!conf) {
return DEFAULT;
}
@@ -8814,7 +8814,7 @@ bool SrsConfig::get_heartbeat_ports()
static bool DEFAULT = false;
- SrsConfDirective* conf = get_heartbeart();
+ SrsConfDirective* conf = get_heartbeat();
if (!conf) {
return DEFAULT;
}
diff --git a/trunk/src/core/srs_core_version5.hpp b/trunk/src/core/srs_core_version5.hpp
index 86448ae40..0f7e16b4f 100644
--- a/trunk/src/core/srs_core_version5.hpp
+++ b/trunk/src/core/srs_core_version5.hpp
@@ -9,6 +9,6 @@
#define VERSION_MAJOR 5
#define VERSION_MINOR 0
-#define VERSION_REVISION 219
+#define VERSION_REVISION 220
#endif
diff --git a/trunk/src/core/srs_core_version6.hpp b/trunk/src/core/srs_core_version6.hpp
index 5487bdce7..63a50acfd 100644
--- a/trunk/src/core/srs_core_version6.hpp
+++ b/trunk/src/core/srs_core_version6.hpp
@@ -9,6 +9,6 @@
#define VERSION_MAJOR 6
#define VERSION_MINOR 0
-#define VERSION_REVISION 160
+#define VERSION_REVISION 161
#endif
diff --git a/trunk/src/app/srs_app_config.hpp b/trunk/src/app/srs_app_config.hpp
index 6426bc11e..bfb87445f 100644
--- a/trunk/src/app/srs_app_config.hpp
+++ b/trunk/src/app/srs_app_config.hpp
@@ -1104,10 +1104,10 @@ public:
// Get the http flv live stream mount point for vhost.
// used to generate the flv stream mount path.
virtual std::string get_vhost_http_remux_mount(std::string vhost);
// http heartbeart section
private:
// Get the heartbeat directive.
- virtual SrsConfDirective* get_heartbeart();
+ virtual SrsConfDirective* get_heartbeat();
public:
// Whether heartbeat enabled.
virtual bool get_heartbeat_enabled();
@@ -1104,10 +1104,10 @@ public:
// used to generate the flv stream mount path.
virtual std::string get_vhost_http_remux_mount(std::string vhost);
-// http heartbeart section
+// http heartbeat section
private:
// Get the heartbeat directive.